@@ -35,7 +35,7 @@ namespace gbrainy.Core.Main
 		private bool preview;
 		private GameDifficulty difficulty;
 		private ISynchronizeInvoke synchronize;
-		private List <Toolkit.Container> containers;
+		private readonly List <Toolkit.Container> containers;
 		private int variant;
 		private GameAnswer answer;
 
@@ -45,9 +45,9 @@ namespace gbrainy.Core.Main
 
 		protected Game ()
 		{
+			answer = new GameAnswer ();
 			containers = new List <Toolkit.Container> ();
 			difficulty = GameDifficulty.Medium;
-			answer = new GameAnswer ();
 		}
 
 		public GameAnswer Answer {
@@ -55,6 +55,16 @@ namespace gbrainy.Core.Main
 			set {answer = value; }
 		}
 
+		// At some point, we may move this to constructor injection
+		ITranslations _translations;
+		public ITranslations Translations {
+			set {  
+				_translations = value;
+				answer.Translations = value;
+			}
+			get { return _translations; }
+		}
+
 #region Methods to override in your own games
 
 		public abstract string Name {
@@ -121,18 +131,18 @@ namespace gbrainy.Core.Main
 		}
 
 		// Builds a text answer for the puzzle
-		public string AnswerText {
+		public virtual string AnswerText {
 			get {
 				string str;
 
-				str = String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("The correct answer is {0}."),
+				str = String.Format (Translations.GetString ("The correct answer is {0}."),
 				                     Answer.CorrectShow);
 
 				if (String.IsNullOrEmpty (Rationale))
 					return str;
 
 				// Translators: answer + rationale of the answer
-				return String.Format (ServiceLocator.Instance.GetService <ITranslations> ().GetString ("{0} {1}"), str, Rationale);
+				return String.Format (Translations.GetString ("{0} {1}"), str, Rationale);
 			}
 		}
 
@@ -255,7 +265,7 @@ namespace gbrainy.Core.Main
 			};
 
 			// If the user has selected an item we should propagate an answer
-			container.SelectedEvent += delegate (object sender, SeletectedEventArgs e)
+			container.SelectedEvent += delegate (object sender, SelectedEventArgs e)
 			{
 				if (AnswerEvent != null)
 					AnswerEvent (this, new GameAnswerEventArgs ((string) e.DataEx));
