@@ -18,10 +18,10 @@
  */
 
 using System;
-using Mono.Unix;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Toolkit;
+using gbrainy.Core.Services;
 
 namespace gbrainy.Games.Calculation
 {
@@ -34,7 +34,7 @@ namespace gbrainy.Games.Calculation
 		private int which;
 
 		public override string Name {
-			get {return Catalog.GetString ("Closer fraction");}
+			get {return Translations.GetString ("Closer fraction");}
 		}
 
 		public override GameTypes Type {
@@ -43,21 +43,23 @@ namespace gbrainy.Games.Calculation
 
 		public override string Question {
 			get {return String.Format (
-				Catalog.GetString ("Which of the following numbers is closer to {0:##0.###}? Answer {1}, {2}, {3} or {4}."), question_num,
-				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3));}
+				Translations.GetString ("Which of the following numbers is closer to {0}? Answer {1}, {2}, {3} or {4}."),
+				String.Format ("{0:##0.###}", question_num),
+				Answer.GetMultiOption (0), Answer.GetMultiOption (1), Answer.GetMultiOption (2), Answer.GetMultiOption (3));}
 		}
 
 		public override string Rationale {
 			get {
 				int ans_idx = random_indices[which];
 
-				return String.Format (Catalog.GetString ("The result of the operation {0} / {1} is {2:##0.###}"), 
-					options[ans_idx * 2], options[(ans_idx * 2) + 1], question_num);
+				return String.Format (Translations.GetString ("The result of the operation {0} / {1} is '{2}'."),
+					options[ans_idx * 2], options[(ans_idx * 2) + 1], String.Format ("{0:##0.###}", question_num));
 			}
 		}
 
 		protected override void Initialize ()
-		{	
+		{
+			Answer.CheckAttributes |= GameAnswerCheckAttributes.MultiOption | GameAnswerCheckAttributes.IgnoreSpaces;
 			options = new double [options_cnt * 2];
 			bool duplicated;
 			bool done = false;
@@ -83,13 +85,13 @@ namespace gbrainy.Games.Calculation
 				duplicated = false;
 				options[0 + 0] = basenum + random.Next (randnum);
 				options[0 + 1] = basenum + random.Next (randnum);
-				
+
 				options[2 + 0] = options[0 + 0] + random.Next (2);
 				options[2 + 1] = options[0 + 1] + random.Next (2);
 
 				options[(2 * 2) + 0] = options[0 + 0] - random.Next (5);
 				options[(2 * 2) + 1] = options[0 + 1] - random.Next (5);
-		
+
 				options[(3 * 2) + 0] = options[0 + 0] +  random.Next (5);
 				options[(3 * 2) + 1] = options[0 + 1] +  random.Next (5);
 
@@ -110,7 +112,7 @@ namespace gbrainy.Games.Calculation
 
 				if (duplicated)
 					continue;
-			
+
 				// No numerator = denominator (1 value)
 				if (options [0 + 0] == options [0 + 1]) continue;
 				if (options [(1 * 2) + 0] == options [(1 * 2) + 1]) continue;
@@ -125,23 +127,24 @@ namespace gbrainy.Games.Calculation
 
 				if (i < options_cnt * 2)
 					continue;
-							
+
 				done = true;
 			}
 
 			random_indices = new ArrayListIndicesRandom (4);
 			random_indices.Initialize ();
-		
+
 			which = random.Next (options_cnt);
 			ans_idx = random_indices[which];
 			question_num = options[ans_idx * 2] / options[(ans_idx * 2) + 1];
-			right_answer += GetPossibleAnswer (which);
+
+			Answer.SetMultiOptionAnswer (which, options [ans_idx * 2] +  " / " + options [(ans_idx  * 2) +1]);
 
 			// Options
 			double x = DrawAreaX + 0.25, y = DrawAreaY + 0.16;
 			Container container = new Container (x, y,  1 - (x * 2), 0.6);
 			AddWidget (container);
-	
+
 			for (i = 0; i < options_cnt; i++)
 			{
 				DrawableArea drawable_area = new DrawableArea (0.3, 0.1);
@@ -149,7 +152,7 @@ namespace gbrainy.Games.Calculation
 				drawable_area.Y = y + i * 0.15;
 				container.AddChild (drawable_area);
 				drawable_area.Data = i;
-				drawable_area.DataEx = GetPossibleAnswer (i);
+				drawable_area.DataEx = Answer.GetMultiOption (i);
 
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 				{
@@ -158,10 +161,20 @@ namespace gbrainy.Games.Calculation
 
 					e.Context.SetPangoLargeFontSize ();
 					e.Context.MoveTo (0.02, 0.02);
-					e.Context.ShowPangoText (String.Format (Catalog.GetString ("{0}) {1}"), GetPossibleAnswer (n) , 
+					e.Context.ShowPangoText (String.Format (Translations.GetString ("{0}) {1}"), Answer.GetMultiOption (n) ,
 						options [indx * 2] +  " / " + options [(indx  * 2) +1]));
 				};
 			}
 		}
+
+		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
+		{
+			base.Draw (gr, area_width, area_height, rtl);
+
+			gr.SetPangoLargeFontSize ();
+
+			gr.MoveTo (0.1, 0.15);
+			gr.ShowPangoText (Translations.GetString ("Choose one of the following:"));
+		}
 	}
 }
